package de.doggoat.growableRebalance.listeners;

import de.doggoat.growableRebalance.PlantUtils;
import org.bukkit.Location;
import org.bukkit.Material;
import org.bukkit.event.Listener;
import org.bukkit.event.EventHandler;
import org.bukkit.event.block.BlockSpreadEvent;
import org.bukkit.plugin.java.JavaPlugin;
import java.util.logging.Logger;
import java.util.Arrays;
import java.util.List;

public class BlockSpreadEventListener implements Listener {

    JavaPlugin plugin;
    Logger log;
    List<Material> allowedKelpGrowthBlocks = Arrays.asList(
            Material.DIRT, Material.SAND, Material.RED_SAND
    );
    List<Material> forbiddenBambooGrowthBlocks = Arrays.asList(
            Material.MOSS_BLOCK, Material.MUD, Material.MUDDY_MANGROVE_ROOTS,
            Material.GRAVEL, Material.SUSPICIOUS_GRAVEL,
            Material.SAND, Material.SUSPICIOUS_SAND
    );

    public BlockSpreadEventListener(JavaPlugin plugin) {
        this.plugin = plugin;
        this.log = plugin.getLogger();
    }

    @EventHandler
    public void onBlockSpread(BlockSpreadEvent e) {
        switch (e.getSource().getType()) {
            case Material.KELP:
                this.onKelpSpread(e);
                break;
            case Material.BAMBOO:
                this.onBambooSpread(e);
                break;
            default:
                log.info("BlockSpreadEvent: Source " + e.getSource().getType());
                break;
        }
    }

    public void onKelpSpread(BlockSpreadEvent e) {
        Location plantStart = e.getSource().getLocation();
        Location plantGround = PlantUtils.getVerticalPlantGround(plantStart);
        if (!allowedKelpGrowthBlocks.contains(plantGround.getBlock().getType())) {
            e.setCancelled(true);
        }
    }

    public void onBambooSpread(BlockSpreadEvent e) {
        Location plantStart = e.getBlock().getLocation().add(0, -1, 0);
        Location plantGround = PlantUtils.getVerticalPlantGround(plantStart);
        if (forbiddenBambooGrowthBlocks.contains(plantGround.getBlock().getType())) {
            e.setCancelled(true);
        }
    }
}
